@@ -2,7 +2,7 @@
  *  \file  Gaussian3D.cpp
  *  \brief Gaussian shape
  *
- *  Copyright 2007-2021 IMP Inventors. All rights reserved.
+ *  Copyright 2007-2022 IMP Inventors. All rights reserved.
  */
 #include "IMP/algebra/Gaussian3D.h"
 
@@ -94,7 +94,7 @@ DensityGrid get_rasterized(const Gaussian3Ds &gmm, const Floats &weights,
     double pre(get_gaussian_eval_prefactor(determinant));
     Eigen::Vector3d center(gmm[ng].get_center().get_data());
     IMP_INTERNAL_CHECK(invertible, "matrix wasn't invertible! uh oh!");
-    IMP_FOREACH(const DensityGrid::Index & i, ret.get_all_indexes()) {
+    for(const DensityGrid::Index & i : ret.get_all_indexes()) {
       Eigen::Vector3d r(get_vec_from_center(i, ret, center));
       update_value(&ret, i, r, inverse, pre, weights[ng]);
     }
