@@ -5,6 +5,7 @@ import io
 import math
 import sys
 import pickle
+import operator
 
 
 class Tests(IMP.test.TestCase):
@@ -20,7 +21,7 @@ class Tests(IMP.test.TestCase):
     def test_uninit(self):
         """Check use of uninitialized Vector3D"""
         v = IMP.algebra.Vector3D()
-        self.assertRaises(IMP.UsageException, v.__getitem__, 0)
+        self.assertRaises(IMP.InternalException, v.__getitem__, 0)
 
     def test_from_floats(self):
         """Check Vector3D from floats"""
@@ -93,6 +94,35 @@ class Tests(IMP.test.TestCase):
         v1 = IMP.algebra.Vector3D(1.0, 2.0, 3.0)
         self.assertEqual(len(v1), 3)
 
+    def test_dimension_mismatch(self):
+        """Check failure to combine with other dimension vectors"""
+        v3 = IMP.algebra.Vector3D(1.0, 2.0, 3.0)
+        v4 = IMP.algebra.Vector4D(1.0, 2.0, 3.0, 4.0)
+        k3 = IMP.algebra.VectorKD(v3)
+        k4 = IMP.algebra.VectorKD(v4)
+        # Should not be able to add 3D vector to 4D (or KD with K==4) vector
+        self.assertRaises(TypeError, operator.add, v3, v4)
+        self.assertRaises(TypeError, operator.add, v3, k4)
+        self.assertRaises(TypeError, operator.add, v4, v3)
+        self.assertRaises(TypeError, operator.add, v4, k3)
+        # Should not be able to subtract 3D vector from
+        # 4D (or KD with K==4) vector
+        self.assertRaises(TypeError, operator.sub, v3, v4)
+        self.assertRaises(TypeError, operator.sub, v3, k4)
+        self.assertRaises(TypeError, operator.sub, v4, v3)
+        self.assertRaises(TypeError, operator.sub, v4, k3)
+        # Should not be able to get scalar product 3D vector with 4D
+        self.assertRaises(TypeError, v3.get_scalar_product, v4)
+        self.assertRaises(TypeError, v3.get_scalar_product, k4)
+        self.assertRaises(TypeError, v4.get_scalar_product, v3)
+        self.assertRaises(TypeError, v4.get_scalar_product, k3)
+        # 3D vector with KD (with K==3) is OK, but scalar product is
+        # not currently supported
+        _ = v3 + k3
+        _ = v3 - k3
+        self.assertRaises(TypeError, v3.get_scalar_product, k3)
+        self.assertRaises(TypeError, k3.get_scalar_product, v3)
+
     def test_scalar_product(self):
         """Check Vector3D scalar product"""
         v1 = IMP.algebra.Vector3D(1.0, 2.0, 3.0)
@@ -140,6 +170,19 @@ class Tests(IMP.test.TestCase):
         self.assertAlmostEqual((v1 - expected_diff).get_magnitude(),
                                0, delta=.1)
 
+    def test_get_distance(self):
+        """Check Vector3D.get_distance()"""
+        v1 = IMP.algebra.Vector3D(1.0, 2.0, 3.0)
+        v2 = IMP.algebra.Vector3D(10.0, 1.0, 2.0)
+        dist = v1.get_distance(v2)
+        self.assertAlmostEqual(dist, 9.11, delta=0.01)
+        dist2 = (v1 - v2).get_magnitude()
+        self.assertAlmostEqual(dist, dist2, delta=0.01)
+        # Should not be able to get distance between different
+        # dimension vectors
+        v4 = IMP.algebra.Vector4D(10.0, 1.0, 2.0, 0.0)
+        self.assertRaises(TypeError, v1.get_distance, v4)
+
     def test_show(self):
         """Check vector 3D show"""
         v = IMP.algebra.Vector3D(1, 2, 3)
