@@ -2,7 +2,7 @@
  *  \file internal/pdb.h
  *  \brief A class with static functions for parsing PDB files
  *
- *  Copyright 2007-2022 IMP Inventors. All rights reserved.
+ *  Copyright 2007-2023 IMP Inventors. All rights reserved.
  *
  */
 
@@ -17,6 +17,9 @@
 
 #include <vector>
 
+struct ihm_keyword;
+struct ihm_category;
+
 IMPATOM_BEGIN_INTERNAL_NAMESPACE
 
 //! Make an Atom Particle given information extracted from a PDB file
@@ -57,7 +60,7 @@ IMPATOMEXPORT bool is_CONECT_rec(const String& pdb_line);
 IMPATOMEXPORT int model_index(const String& pdb_line);
 
 /** Returns a string with an atom type string.
-    The atom type is a 4 charachter long field.
+    The atom type is a 4 character long field.
     the first character is space in many cases, but not always. */
 IMPATOMEXPORT String atom_type(const String& pdb_line);
 
@@ -111,6 +114,23 @@ IMPATOMEXPORT String atom_element(const String& pdb_line);
 IMPATOMEXPORT Vector<unsigned short> connected_atoms(
     const String& pdb_line);
 
+//! Handle a keyword in an mmCIF file
+class IMPATOMEXPORT CifKeyword {
+  struct ihm_keyword *k_;
+public:
+  CifKeyword(struct ihm_category *c, std::string name);
+
+  //! Get raw string value of the keyword (may be null)
+  const char *data();
+
+  //! Get value as a string, or the empty string if it is missing
+  const char *as_str();
+
+  float as_float(float default_value=0.);
+
+  int as_int(int default_value=0);
+};
+
 //! write particles as ATOMs to PDB (assumes Particles are valid Atoms)
 IMPATOMEXPORT void write_pdb(const ParticlesTemp& ps,
                              TextOutput out);
