@@ -1,7 +1,7 @@
 /**
  *  \file Atom.cpp   \brief Simple atoms decorator.
  *
- *  Copyright 2007-2021 IMP Inventors. All rights reserved.
+ *  Copyright 2007-2022 IMP Inventors. All rights reserved.
  *
  */
 
@@ -20,7 +20,7 @@ IMPATOM_BEGIN_NAMESPACE
 
 double get_resolution(Model* m, ParticleIndex pi) {
   double min = std::numeric_limits<double>::max();
-  IMP_FOREACH(Hierarchy l, get_leaves(Hierarchy(m, pi))) {
+  for(Hierarchy l : get_leaves(Hierarchy(m, pi))) {
     double cur = core::XYZR(l).get_radius();
     IMP_USAGE_CHECK(cur > 0, "Particle " << l << " has an invalid radius");
     min = std::min(min, cur);
