@@ -352,13 +352,13 @@ class Tests(IMP.test.TestCase):
         self.assertEqual(len(atoms), 43)
         a = atoms[-2]
         # Make sure we kept the original PDB coordinates
-        coord = a.get_as_xyz().get_coordinates()
+        coord = IMP.core.XYZ(a).get_coordinates()
         self.assertAlmostEqual(coord[0], 20.149, delta=1e-3)
         self.assertAlmostEqual(coord[1], 33.749, delta=1e-3)
         self.assertAlmostEqual(coord[2], 3.830, delta=1e-3)
         # Make sure all atoms are HETATM
         for a in atoms:
-            self.assertEqual(a.get_as_atom().get_atom_type().get_string()[:4],
+            self.assertEqual(IMP.atom.Atom(a).get_atom_type().get_string()[:4],
                              "HET:")
 
     def test_add_coordinates_empty_structure(self):
@@ -375,30 +375,6 @@ class Tests(IMP.test.TestCase):
         for a in IMP.atom.get_by_type(hierarchy, IMP.atom.ATOM_TYPE):
             self.assertTrue(IMP.core.XYZ.get_is_setup(a))
 
-    def test_add_sequence(self):
-        """Test CHARMMTopology::add_sequence()"""
-        ff = IMP.atom.CHARMMParameters(IMP.atom.get_data_path("top.lib"),
-                                       IMP.atom.get_data_path("par.lib"))
-        t = IMP.atom.CHARMMTopology(ff)
-        self.assertEqual(t.get_number_of_segments(), 0)
-        # Should add an empty segment
-        t.add_sequence('')
-        self.assertEqual(t.get_number_of_segments(), 1)
-        self.assertEqual(t.get_segment(0).get_number_of_residues(), 0)
-
-        # Should add two non-empty segments
-        t = IMP.atom.CHARMMTopology(ff)
-        t.add_sequence('ACY/MF')
-        self.assertEqual(t.get_number_of_segments(), 2)
-        self.assertEqual(t.get_segment(0).get_number_of_residues(), 3)
-        self.assertEqual(t.get_segment(1).get_number_of_residues(), 2)
-
-        # Invalid one-letter codes should cause an exception and add no
-        # segments
-        t = IMP.atom.CHARMMTopology(ff)
-        self.assertRaises(ValueError, t.add_sequence, 'a')
-        self.assertEqual(t.get_number_of_segments(), 0)
-
     def test_make_patched_topology(self):
         """Test construction of topology with manual patching"""
         m = IMP.Model()
@@ -415,8 +391,8 @@ class Tests(IMP.test.TestCase):
         residues = IMP.atom.get_by_type(pdb, IMP.atom.RESIDUE_TYPE)
         # LINK residue should have constructed a backbone bond between the
         # first and last residues
-        r1 = residues[-1].get_as_residue()
-        r2 = residues[0].get_as_residue()
+        r1 = IMP.atom.Residue(residues[-1])
+        r2 = IMP.atom.Residue(residues[0])
         a1 = IMP.atom.get_atom(r1, IMP.atom.AT_C)
         a2 = IMP.atom.get_atom(r2, IMP.atom.AT_N)
         self.assertAtomsBonded(a1, a2, 'C', 'NH1', 1.3450, 27.203)
@@ -523,8 +499,8 @@ class Tests(IMP.test.TestCase):
             # CTER bond
             (residues[-1], residues[-1], IMP.atom.AT_OXT, IMP.atom.AT_C,
                 'OC', 'CC', 1.2600, 32.404)]:
-            r1 = bondr1.get_as_residue()
-            r2 = bondr2.get_as_residue()
+            r1 = IMP.atom.Residue(bondr1)
+            r2 = IMP.atom.Residue(bondr2)
             a1 = IMP.atom.get_atom(r1, bonda1)
             a2 = IMP.atom.get_atom(r2, bonda2)
             self.assertAtomsBonded(a1, a2, atyp1, atyp2, bondlen, fcon)
@@ -605,6 +581,33 @@ class Tests(IMP.test.TestCase):
         atoms = IMP.atom.get_by_type(pdb, IMP.atom.ATOM_TYPE)
         self.assertEqual(len(atoms), 7)
 
+    def test_warn_previously_typed(self):
+        """Test warning about previously-typed CHARMM atoms"""
+        m = IMP.Model()
+        pdb = IMP.atom.read_pdb(
+            self.get_input_file_name('charmm_type_test.pdb'), m)
+        ff = IMP.atom.CHARMMParameters(IMP.atom.get_data_path("top.lib"),
+                                       IMP.atom.get_data_path("par.lib"))
+        atoms = IMP.atom.get_by_type(pdb, IMP.atom.ATOM_TYPE)
+        # Set manual CHARMM atom types
+        dum, = [a for a in atoms
+                if IMP.atom.Atom(a).get_atom_type().get_string() == 'DUM']
+        ca1, ca2, = [a for a in atoms
+                if IMP.atom.Atom(a).get_atom_type().get_string() == 'CA']
+        IMP.atom.CHARMMAtom.setup_particle(dum, "OD")
+        IMP.atom.CHARMMAtom.setup_particle(ca1, "N")
+
+        topology = ff.create_topology(pdb)
+        topology.apply_default_patches()
+        topology.add_atom_types(pdb)
+
+        # dum should have kept its original type, OD
+        self.assertEqual(IMP.atom.CHARMMAtom(dum).get_charmm_type(), 'OD')
+        # ca1 should have been assigned the correct type
+        self.assertEqual(IMP.atom.CHARMMAtom(ca1).get_charmm_type(), 'CT1')
+        untyped = IMP.atom.get_charmm_untyped_atoms(pdb)
+        self.assertEqual(len(untyped), 0)
+
     def test_add_missing_atoms(self):
         """Test adding missing atoms"""
         m = IMP.Model()
