@@ -11,8 +11,9 @@ def parse_args():
     This program builds cyclic symmetric complexes in their density maps."""
 
     parser = ArgumentParser(description=desc)
-    parser.add_argument("--chimera", dest="chimera", default="", metavar="FILE",
-                      help="the name of the Chimera output file, if desired")
+    parser.add_argument("--chimera", dest="chimera", default="",
+                        metavar="FILE",
+                        help="the name of the Chimera output file, if desired")
     parser.add_argument("param_file", help="parameter file name")
     return parser.parse_args()
 
@@ -22,5 +23,6 @@ def main():
     args = parse_args()
     IMP.cnmultifit.do_all_fitting(args.param_file, args.chimera)
 
+
 if __name__ == '__main__':
     main()
