@@ -2,7 +2,7 @@
  *  \file IMP/core/BallMover.h
  *  \brief A modifier which variables within a ball.
  *
- *  Copyright 2007-2019 IMP Inventors. All rights reserved.
+ *  Copyright 2007-2023 IMP Inventors. All rights reserved.
  *
  */
 
@@ -13,6 +13,9 @@
 #include <IMP/base_types.h>
 #include <IMP/exception.h>
 #include "MonteCarloMover.h"
+#include <cereal/access.hpp>
+#include <cereal/types/base_class.hpp>
+#include <cereal/types/polymorphic.hpp>
 
 IMPCORE_BEGIN_NAMESPACE
 
@@ -26,6 +29,14 @@ class IMPCOREEXPORT BallMover : public MonteCarloMover {
   double radius_;
   algebra::VectorKDs originals_;
 
+  friend class cereal::access;
+
+  template<class Archive> void serialize(Archive &ar) {
+    ar(cereal::base_class<MonteCarloMover>(this),
+       pis_, keys_, radius_, originals_);
+  }
+  IMP_OBJECT_SERIALIZE_DECL(BallMover);
+
   void initialize(ParticleIndexes pis, FloatKeys keys, double radius);
 
  public:
@@ -56,6 +67,8 @@ class IMPCOREEXPORT BallMover : public MonteCarloMover {
    */
   BallMover(Model *m, const ParticleIndexes &pis, Float radius);
 
+  BallMover() {}
+
   void set_radius(Float radius) {
     IMP_ALWAYS_CHECK(radius > 0, "The radius must be positive",
                      IMP::ValueException);
@@ -65,13 +78,13 @@ class IMPCOREEXPORT BallMover : public MonteCarloMover {
   Float get_radius() const { return radius_; }
 
  protected:
-  virtual ModelObjectsTemp do_get_inputs() const IMP_OVERRIDE;
+  virtual ModelObjectsTemp do_get_inputs() const override;
 
   //! Move particle attributes within a ball, as specified in constructor
-  virtual MonteCarloMoverResult do_propose() IMP_OVERRIDE;
+  virtual MonteCarloMoverResult do_propose() override;
 
   //! Restore original attributes from before do_propose()
-  virtual void do_reject() IMP_OVERRIDE;
+  virtual void do_reject() override;
   IMP_OBJECT_METHODS(BallMover);
 };
 
