@@ -46,12 +46,12 @@ struct TransformParticle {
 double TransformedDistancePairScore::evaluate_index(
     Model *m, const ParticleIndexPair &pip,
     DerivativeAccumulator *da) const {
-  TransformParticle tb(t_, ri_, m, pip[1]);
+  TransformParticle tb(t_, ri_, m, std::get<1>(pip));
   IMP_LOG_VERBOSE("Transformed particle is "
                   << tb.get_coordinate(0) << " " << tb.get_coordinate(1) << " "
                   << tb.get_coordinate(2) << std::endl);
   Float ret = internal::evaluate_distance_pair_score(
-      XYZ(m, pip[0]), tb, da, f_.get(), boost::lambda::_1);
+      XYZ(m, std::get<0>(pip)), tb, da, f_.get(), boost::lambda::_1);
   return ret;
 }
 
