@@ -2,7 +2,7 @@
  *  \file provenance.cpp
  *  \brief Classes to track how the model was created.
  *
- *  Copyright 2007-2022 IMP Inventors. All rights reserved.
+ *  Copyright 2007-2023 IMP Inventors. All rights reserved.
  */
 
 #include <IMP/core/provenance.h>
@@ -44,8 +44,8 @@ Provenance clone_one(Provenance prov) {
 
 } // anonymous namespace
 
-ParticleIndexKey Provenanced::get_provenance_key() {
-  static const ParticleIndexKey provenance("provenance");
+SparseParticleIndexKey Provenanced::get_provenance_key() {
+  static const SparseParticleIndexKey provenance("provenance");
   return provenance;
 }
 
@@ -53,8 +53,8 @@ void Provenanced::show(std::ostream &out) const {
   out << "Provenanced" << std::endl;
 }
 
-ParticleIndexKey Provenance::get_previous_key() {
-  static const ParticleIndexKey previous("previous_provenance");
+SparseParticleIndexKey Provenance::get_previous_key() {
+  static const SparseParticleIndexKey previous("previous_provenance");
   return previous;
 }
 
@@ -62,18 +62,18 @@ void Provenance::show(std::ostream &out) const {
   out << "Provenance" << std::endl;
 }
 
-StringKey StructureProvenance::get_filename_key() {
-  static const StringKey filename("sp_filename");
+SparseStringKey StructureProvenance::get_filename_key() {
+  static const SparseStringKey filename("sp_filename");
   return filename;
 }
 
-StringKey StructureProvenance::get_chain_key() {
-  static const StringKey chain("sp_chain");
+SparseStringKey StructureProvenance::get_chain_key() {
+  static const SparseStringKey chain("sp_chain");
   return chain;
 }
 
-IntKey StructureProvenance::get_residue_offset_key() {
-  static const IntKey offset("sp_offset");
+SparseIntKey StructureProvenance::get_residue_offset_key() {
+  static const SparseIntKey offset("sp_offset");
   return offset;
 }
 
@@ -92,23 +92,23 @@ std::set<std::string>& SampleProvenance::get_allowed_methods() {
   return m;
 }
 
-StringKey SampleProvenance::get_method_key() {
-  static const StringKey method("sp_method");
+SparseStringKey SampleProvenance::get_method_key() {
+  static const SparseStringKey method("sp_method");
   return method;
 }
 
-IntKey SampleProvenance::get_frames_key() {
-  static const IntKey frames("sp_frames");
+SparseIntKey SampleProvenance::get_frames_key() {
+  static const SparseIntKey frames("sp_frames");
   return frames;
 }
 
-IntKey SampleProvenance::get_iterations_key() {
-  static const IntKey iterations("sp_iterations");
+SparseIntKey SampleProvenance::get_iterations_key() {
+  static const SparseIntKey iterations("sp_iterations");
   return iterations;
 }
 
-IntKey SampleProvenance::get_replicas_key() {
-  static const IntKey replicas("sp_replicas");
+SparseIntKey SampleProvenance::get_replicas_key() {
+  static const SparseIntKey replicas("sp_replicas");
   return replicas;
 }
 
@@ -117,13 +117,13 @@ void SampleProvenance::show(std::ostream &out) const {
       << get_method() << std::endl;
 }
 
-IntKey CombineProvenance::get_runs_key() {
-  static const IntKey runs("cp_runs");
+SparseIntKey CombineProvenance::get_runs_key() {
+  static const SparseIntKey runs("cp_runs");
   return runs;
 }
 
-IntKey CombineProvenance::get_frames_key() {
-  static const IntKey frames("cp_frames");
+SparseIntKey CombineProvenance::get_frames_key() {
+  static const SparseIntKey frames("cp_frames");
   return frames;
 }
 
@@ -133,18 +133,18 @@ void CombineProvenance::show(std::ostream &out) const {
       << " frames" << std::endl;
 }
 
-IntKey ClusterProvenance::get_members_key() {
-  static const IntKey members("cp_members");
+SparseIntKey ClusterProvenance::get_members_key() {
+  static const SparseIntKey members("cp_members");
   return members;
 }
 
-FloatKey ClusterProvenance::get_precision_key() {
-  static const FloatKey precision("cp_precision");
+SparseFloatKey ClusterProvenance::get_precision_key() {
+  static const SparseFloatKey precision("cp_precision");
   return precision;
 }
 
-StringKey ClusterProvenance::get_density_key() {
-  static const StringKey density("cp_density");
+SparseStringKey ClusterProvenance::get_density_key() {
+  static const SparseStringKey density("cp_density");
   return density;
 }
 
@@ -163,18 +163,18 @@ std::set<std::string>& FilterProvenance::get_allowed_methods() {
   return m;
 }
 
-StringKey FilterProvenance::get_method_key() {
-  static const StringKey method("fp_method");
+SparseStringKey FilterProvenance::get_method_key() {
+  static const SparseStringKey method("fp_method");
   return method;
 }
 
-FloatKey FilterProvenance::get_threshold_key() {
-  static const FloatKey threshold("fp_threshold");
+SparseFloatKey FilterProvenance::get_threshold_key() {
+  static const SparseFloatKey threshold("fp_threshold");
   return threshold;
 }
 
-IntKey FilterProvenance::get_frames_key() {
-  static const IntKey frames("fp_frames");
+SparseIntKey FilterProvenance::get_frames_key() {
+  static const SparseIntKey frames("fp_frames");
   return frames;
 }
 
@@ -183,8 +183,8 @@ void FilterProvenance::show(std::ostream &out) const {
       << " resulting in " << get_number_of_frames() << " frames" << std::endl;
 }
 
-StringKey ScriptProvenance::get_filename_key() {
-  static const StringKey filename("script_filename");
+SparseStringKey ScriptProvenance::get_filename_key() {
+  static const SparseStringKey filename("script_filename");
   return filename;
 }
 
@@ -192,18 +192,18 @@ void ScriptProvenance::show(std::ostream &out) const {
   out << "ScriptProvenance " << get_filename() << std::endl;
 }
 
-StringKey SoftwareProvenance::get_name_key() {
-  static const StringKey name("software_name");
+SparseStringKey SoftwareProvenance::get_name_key() {
+  static const SparseStringKey name("software_name");
   return name;
 }
 
-StringKey SoftwareProvenance::get_version_key() {
-  static const StringKey version("software_version");
+SparseStringKey SoftwareProvenance::get_version_key() {
+  static const SparseStringKey version("software_version");
   return version;
 }
 
-StringKey SoftwareProvenance::get_location_key() {
-  static const StringKey location("software_location");
+SparseStringKey SoftwareProvenance::get_location_key() {
+  static const SparseStringKey location("software_location");
   return location;
 }
 
