@@ -1,16 +1,16 @@
 ## \example domino/marina_party.py
 #
-# This is a not very serious example that shows how to use domino from scratch to
-# solve a problem. It is illustrative of creating your own type of particles,
-# a pair score, particle states for DOMINO, a decorator, and using subset filter
-# tables with DOMINO.
+# This is a not very serious example that shows how to use domino from scratch
+# to solve a problem. It is illustrative of creating your own type of
+# particles, a pair score, particle states for DOMINO, a decorator, and using
+# subset filter tables with DOMINO.
 #
 # Solution of the Marina Party Problem with DOMINO:
 #
-# - Girls attend to a party
+# - Girls attend a party
 # - Each girl has dresses of different price
 # - There can not be repeated dresses in the party within a group of connected
-# people
+#   people
 # - Girls that are friends can call each other to agree
 # - The objective is to maximize the total price of all dresses in the party
 #
@@ -21,17 +21,20 @@ import IMP
 import IMP.domino
 import IMP.core
 import random
+import sys
+
+IMP.setup_from_argv(sys.argv, "marina party")
 
 
 class SumPricePairScore(IMP.PairScore):
 
-    def evaluate(self, pair, accum):
-        price0 = Price(pair[0]).get_price()
-        price1 = Price(pair[1]).get_price()
+    def evaluate_index(self, m, pair, accum):
+        price0 = Price(m.get_particle(pair[0])).get_price()
+        price1 = Price(m.get_particle(pair[1])).get_price()
         return price0 + price1
 
     def do_get_inputs(self, m, pis):
-        return [m.get_particle(i) for i in pis]
+        return IMP.get_particles(m, pis)
 
 
 class PriceStates(IMP.domino.ParticleStates):
@@ -81,7 +84,6 @@ def get_total_price(states_table, subset, assignment):
 
 
 def print_assignment(states_table, subset, assignment):
-    total_price = 0
     print("########## solution assignment", assignment)
     for i, p in enumerate(subset):
         price_states = states_table.get_particle_states(p)
@@ -96,7 +98,7 @@ girls = []
 prices = [100, 200, 400, 600, 800]
 
 
-model = IMP.kernel.Model()
+model = IMP.Model()
 
 # prepare filter tables for DOMINO
 states_table = IMP.domino.ParticleStatesTable()
@@ -106,7 +108,7 @@ all_possible_states = PriceStates(prices)
 
 # set_states
 for i in range(n_girls):
-    p = IMP.kernel.Particle(model, "girl-%d" % i)
+    p = IMP.Particle(model, "girl-%d" % i)
     pr = Price(p)
     girls.append(p)
     # add possible dresses
@@ -121,25 +123,27 @@ for i in range(n_girls):
     # Each girl has a selection of dresses
     selection = random.sample(prices, n_dresses)
     allowed_states_indices = [prices.index(price) for price in selection]
-    print(p.get_name(), "prices selected", selection, "indices", allowed_states_indices)
+    print(p.get_name(), "prices selected", selection, "indices",
+          allowed_states_indices)
     list_states_table = IMP.domino.ListSubsetFilterTable(states_table)
     list_states_table.set_allowed_states(p, allowed_states_indices)
     sampler.add_subset_filter_table(list_states_table)
 
 # create restraints
+rs = []
 for z in range(n_edges):
     # pair of friends
     i = random.randrange(0, n_girls)
     j = random.randrange(0, n_girls)
-    friends = IMP.kernel.ParticlePair(girls[i], girls[j])
+    friends = IMP.ParticlePair(girls[i], girls[j])
     # restraint
     score = SumPricePairScore()
-    r = IMP.core.PairRestraint(score, friends)
-    model.add_restraint(r)
+    rs.append(IMP.core.PairRestraint(model, score, friends))
     # Exclusion states. Two girls can't have same dress
     ft = IMP.domino.ExclusionSubsetFilterTable()
     ft.add_pair(friends)
     sampler.add_subset_filter_table(ft)
+sampler.set_restraints(rs)
 
 subset = states_table.get_subset()
 solutions = sampler.get_sample_assignments(subset)
