@@ -2,7 +2,7 @@
  *  \file interaction_graph.cpp
  *  \brief Score particles with respect to a tunnel.
  *
- *  Copyright 2007-2021 IMP Inventors. All rights reserved.
+ *  Copyright 2007-2022 IMP Inventors. All rights reserved.
  *
  */
 #include <IMP/domino/analysis.h>
@@ -25,15 +25,15 @@ class ParticleStatesEmbedding : public statistics::Embedding {
   ParticleStatesEmbedding(Particle *p, ParticleStates *ps,
                           const Ints &allowed, std::string name)
       : Embedding(name), p_(p), ps_(ps), allowed_(allowed) {}
-  algebra::VectorKD get_point(unsigned int i) const IMP_OVERRIDE;
-  algebra::VectorKDs get_points() const IMP_OVERRIDE {
+  algebra::VectorKD get_point(unsigned int i) const override;
+  algebra::VectorKDs get_points() const override {
     algebra::VectorKDs ret(get_number_of_items());
     for (unsigned int i = 0; i < ret.size(); ++i) {
       ret[i] = ParticleStatesEmbedding::get_point(i);
     }
     return ret;
   }
-  unsigned int get_number_of_items() const IMP_OVERRIDE;
+  unsigned int get_number_of_items() const override;
   IMP_OBJECT_METHODS(ParticleStatesEmbedding);
 };
 
