@@ -14,7 +14,7 @@
 #include <IMP/core/XYZ.h>
 #include <IMP/isd/Scale.h>
 #include <IMP/isd/Weight.h>
-#include <math.h>
+#include <cmath>
 #include <limits.h>
 #include <IMP/random.h>
 #include <IMP/PairContainer.h>
