@@ -21,19 +21,19 @@ class Tests(IMP.test.TestCase):
 
     def setUp(self):
         IMP.test.TestCase.setUp(self)
-        # IMP.base.set_log_level(IMP.MEMORY)
-        IMP.base.set_log_level(0)
-        self.m = IMP.kernel.Model()
-        self.p0 = IMP.core.XYZ.setup_particle(IMP.kernel.Particle(self.m),
+        # IMP.set_log_level(IMP.MEMORY)
+        IMP.set_log_level(0)
+        self.m = IMP.Model()
+        self.p0 = IMP.core.XYZ.setup_particle(IMP.Particle(self.m),
                                               IMP.algebra.Vector3D(0, 0, 0))
-        self.p1 = IMP.core.XYZ.setup_particle(IMP.kernel.Particle(self.m),
+        self.p1 = IMP.core.XYZ.setup_particle(IMP.Particle(self.m),
                                               IMP.algebra.Vector3D(1, 1, 1))
-        self.p2 = IMP.core.XYZ.setup_particle(IMP.kernel.Particle(self.m),
+        self.p2 = IMP.core.XYZ.setup_particle(IMP.Particle(self.m),
                                               IMP.algebra.Vector3D(1, 0, 0))
         self.DA = IMP.DerivativeAccumulator()
         self.V_obs = 3.0
         self.ls = \
-            IMP.container.ListPairContainer(
+            IMP.container.ListPairContainer(self.m,
                 [(self.p0, self.p1), (self.p0, self.p2)])
         self.noe = IMP.isd.MarginalHBondRestraint(self.m)
 
@@ -43,8 +43,7 @@ class Tests(IMP.test.TestCase):
         p0, p1, p2 = self.p0, self.p1, self.p2
         self.noe.add_contribution(self.p0, self.p1, 1.0)
         self.noe.add_contribution(
-            IMP.container.ListPairContainer([(self.p0, self.p2)]), 2.0)
-        self.m.add_restraint(self.noe)
+            IMP.container.ListPairContainer(self.m, [(self.p0, self.p2)]), 2.0)
         for i in range(100):
             for p in [self.p0, self.p1, self.p2]:
                 p.set_coordinates(IMP.algebra.Vector3D(*[uniform(0.1, 100)
@@ -61,8 +60,7 @@ class Tests(IMP.test.TestCase):
         p0, p1, p2 = self.p0, self.p1, self.p2
         self.noe.add_contribution(self.p0, self.p1, v1)
         self.noe.add_contribution(
-            IMP.container.ListPairContainer([(self.p0, self.p2)]), v2)
-        self.m.add_restraint(self.noe)
+            IMP.container.ListPairContainer(self.m, [(self.p0, self.p2)]), v2)
         for i in range(100):
             for p in [self.p0, self.p1, self.p2]:
                 p.set_coordinates(IMP.algebra.Vector3D(*[uniform(0.1, 100)
@@ -79,19 +77,18 @@ class Tests(IMP.test.TestCase):
         pairs = []
         volumes = []
         distances = []
-        self.m.add_restraint(self.noe)
         for i in range(2, 100):
             while len(pairs) <= i:
                 pair = [IMP.core.XYZ.setup_particle(
-                    IMP.kernel.Particle(self.m),
+                    IMP.Particle(self.m),
                     IMP.algebra.Vector3D(*[uniform(-10, 10) for r in range(3)]))
                     for p in range(2)]
                 pairs.append(pair)
                 distances.append(IMP.core.get_distance(pair[0], pair[1]))
                 volumes.append(uniform(0.1, 10))
                 self.noe.add_contribution(
-                    IMP.container.ListPairContainer([pair]),
-                    volumes[-1])
+                    IMP.container.ListPairContainer(self.m, [pair]),
+                                 volumes[-1])
             expected = 0
             for j in range(len(pairs)):
                 expected += log(volumes[j] / distances[j] ** (-6)) ** 2
@@ -104,18 +101,17 @@ class Tests(IMP.test.TestCase):
         pairs = []
         volumes = []
         distances = []
-        self.m.add_restraint(self.noe)
         for i in range(2, 100):
             while len(pairs) <= i:
                 pair = [IMP.core.XYZ.setup_particle(
-                    IMP.kernel.Particle(self.m),
+                    IMP.Particle(self.m),
                     IMP.algebra.Vector3D(*[uniform(-10, 10) for r in range(3)]))
                     for p in range(2)]
                 pairs.append(pair)
                 distances.append(IMP.core.get_distance(pair[0], pair[1]))
                 volumes.append(uniform(0.1, 10))
                 self.noe.add_contribution(
-                    IMP.container.ListPairContainer([pair]),
+                    IMP.container.ListPairContainer(self.m, [pair]),
                     volumes[-1])
             expected = 0
             for j in range(len(pairs)):
@@ -129,19 +125,18 @@ class Tests(IMP.test.TestCase):
         pairs = []
         volumes = []
         distances = []
-        self.m.add_restraint(self.noe)
         for i in range(2, 100):
             while len(pairs) <= i:
                 pair = [IMP.core.XYZ.setup_particle(
-                    IMP.kernel.Particle(self.m),
+                    IMP.Particle(self.m),
                     IMP.algebra.Vector3D(*[uniform(-10, 10) for r in range(3)]))
                     for p in range(2)]
                 pairs.append(pair)
                 distances.append(IMP.core.get_distance(pair[0], pair[1]))
                 volumes.append(uniform(0.1, 10))
                 self.noe.add_contribution(
-                    IMP.container.ListPairContainer([pair]),
-                    volumes[-1])
+                    IMP.container.ListPairContainer(self.m, [pair]),
+                                    volumes[-1])
             expected = 0
             for j in range(len(pairs)):
                 expected += log(volumes[j] / distances[j] ** (-6)) ** 2
@@ -154,19 +149,18 @@ class Tests(IMP.test.TestCase):
         pairs = []
         volumes = []
         distances = []
-        self.m.add_restraint(self.noe)
         for i in range(2, 100):
             while len(pairs) <= i:
                 pair = [IMP.core.XYZ.setup_particle(
-                    IMP.kernel.Particle(self.m),
+                    IMP.Particle(self.m),
                     IMP.algebra.Vector3D(*[uniform(-10, 10) for r in range(3)]))
                     for p in range(2)]
                 pairs.append(pair)
                 distances.append(IMP.core.get_distance(pair[0], pair[1]))
                 volumes.append(uniform(0.1, 10))
                 self.noe.add_contribution(
-                    IMP.container.ListPairContainer([pair]),
-                    volumes[-1])
+                    IMP.container.ListPairContainer(self.m, [pair]),
+                              volumes[-1])
             expected = len(volumes)
             self.assertAlmostEqual(self.noe.get_number_of_contributions(),
                                    expected, delta=0.001)
@@ -177,8 +171,7 @@ class Tests(IMP.test.TestCase):
         p0, p1, p2 = self.p0, self.p1, self.p2
         self.noe.add_contribution(self.p0, self.p1, v1)
         self.noe.add_contribution(
-            IMP.container.ListPairContainer([(self.p0, self.p2)]), v2)
-        self.m.add_restraint(self.noe)
+            IMP.container.ListPairContainer(self.m, [(self.p0, self.p2)]), v2)
         p0.set_coordinates(IMP.algebra.Vector3D(0, 0, 0))
         p1.set_coordinates(IMP.algebra.Vector3D(1, 1, 1))
         p2.set_coordinates(IMP.algebra.Vector3D(1, 0, 0))
@@ -209,7 +202,7 @@ class Tests(IMP.test.TestCase):
         "Test MarginalHBondRestraint::get_inputs"
         v1, v2 = 1.0, 2.0
         p0, p1, p2 = self.p0, self.p1, self.p2
-        c1 = IMP.container.ListPairContainer([(self.p0, self.p1)])
+        c1 = IMP.container.ListPairContainer(self.m, [(self.p0, self.p1)])
         self.noe.add_contribution(c1, v1)
         self.assertEqual([x.get_name() for x in self.noe.get_inputs()],
                          [y.get_name() for y in [self.p0, self.p1, c1]])
@@ -218,11 +211,10 @@ class Tests(IMP.test.TestCase):
         "Test if MarginalHBond score is -log(prob)"
         v1, v2 = 1.0, 2.0
         p0, p1, p2 = self.p0, self.p1, self.p2
-        c1 = IMP.container.ListPairContainer([(self.p0, self.p1)])
-        c2 = IMP.container.ListPairContainer([(self.p0, self.p2)])
+        c1 = IMP.container.ListPairContainer(self.m, [(self.p0, self.p1)])
+        c2 = IMP.container.ListPairContainer(self.m, [(self.p0, self.p2)])
         self.noe.add_contribution(c1, v1)
         self.noe.add_contribution(c2, v2)
-        self.m.add_restraint(self.noe)
         for i in range(100):
             p0.set_coordinates(IMP.algebra.Vector3D(*[uniform(-10, 10) for i in
                                                       range(3)]))
@@ -233,11 +225,10 @@ class Tests(IMP.test.TestCase):
         "Test if MarginalHBondRestraint prob is exp(-score)"
         v1, v2 = 1.0, 2.0
         p0, p1, p2 = self.p0, self.p1, self.p2
-        c1 = IMP.container.ListPairContainer([(self.p0, self.p1)])
-        c2 = IMP.container.ListPairContainer([(self.p0, self.p2)])
+        c1 = IMP.container.ListPairContainer(self.m, [(self.p0, self.p1)])
+        c2 = IMP.container.ListPairContainer(self.m, [(self.p0, self.p2)])
         self.noe.add_contribution(c1, v1)
         self.noe.add_contribution(c2, v2)
-        self.m.add_restraint(self.noe)
         for i in range(100):
             p0.set_coordinates(IMP.algebra.Vector3D(*[uniform(-10, 10) for i in
                                                       range(3)]))
