@@ -9,7 +9,7 @@
 #include <IMP/random.h>
 #include <IMP/test/test_macros.h>
 #include <IMP/flags.h>
-#include <boost/random/uniform_int.hpp>
+#include <boost/random/uniform_int_distribution.hpp>
 struct PlusOne {
   typedef int result_type;
   typedef int argument_type;
@@ -22,7 +22,7 @@ struct PlusOne {
 int main(int argc, char *argv[]) {
   IMP::setup_from_argv(argc, argv, "Test of base caches in C++");
   IMP::LRUCache<PlusOne> table(PlusOne(), 10);
-  boost::uniform_int<> ui(0, 20);
+  boost::random::uniform_int_distribution<> ui(0, 20);
   for (unsigned int i = 0; i < 10; ++i) {
     int in = i;
     int out = table.get(in);
