@@ -5,7 +5,7 @@
  *  \authors Dina Schneidman, Barak Raveh
  *
 
- *  Copyright 2007-2021 IMP Inventors. All rights reserved.
+ *  Copyright 2007-2022 IMP Inventors. All rights reserved.
  */
 
 #ifndef IMPKINEMATICS_COMPOSITE_JOINT_H
@@ -97,7 +97,7 @@ class IMPKINEMATICSEXPORT CompositeJoint : public Joint {
 
  protected:
   //! Update the child node reference frame by applying all the inner joints
-  virtual void update_child_node_reference_frame() const IMP_OVERRIDE;
+  virtual void update_child_node_reference_frame() const override;
 
   /**
     Updates all inner joints value, and the overall transformation
@@ -108,7 +108,7 @@ class IMPKINEMATICSEXPORT CompositeJoint : public Joint {
           calling this function.
   */
 
-  virtual void update_joint_from_cartesian_witnesses() IMP_OVERRIDE;
+  virtual void update_joint_from_cartesian_witnesses() override;
 
  private:
   Joints joints_;  // list of inner joints
