@@ -3,6 +3,7 @@ import IMP.test
 import sys
 import os
 
+
 class Tests(IMP.test.ApplicationTestCase):
 
     def test_simple(self):
@@ -20,11 +21,11 @@ class Tests(IMP.test.ApplicationTestCase):
 
     def test_no_dofs(self):
         """Test rrt_sample application with no DOFs"""
-        p = self.run_application('rrt_sample',
-                                 [self.get_input_file_name('three.pdb'),
-                                  self.get_input_file_name('hinges.txt'),
-                                  '-c', self.get_input_file_name('connect.txt'),
-                                  '-n', '1'])
+        p = self.run_application(
+            'rrt_sample',
+            [self.get_input_file_name('three.pdb'),
+             self.get_input_file_name('hinges.txt'),
+             '-c', self.get_input_file_name('connect.txt'), '-n', '1'])
         out, err = p.communicate()
         sys.stderr.write(err)
         self.assertNotEqual(p.returncode, 0)
@@ -32,5 +33,6 @@ class Tests(IMP.test.ApplicationTestCase):
         self.assertIn('No degrees of freedom to sample!', err)
         os.unlink('node_begin.pdb')
 
+
 if __name__ == '__main__':
     IMP.test.main()
