@@ -2,7 +2,7 @@
  *  \file IMP/misc/StateAdaptor.h
  *  \brief XXXXXXXXXXXXXX
  *
- *  Copyright 2007-2020 IMP Inventors. All rights reserved.
+ *  Copyright 2007-2022 IMP Inventors. All rights reserved.
  */
 
 #ifndef IMPMISC_STATE_ADAPTOR_H
@@ -24,10 +24,10 @@ class IMPMISCEXPORT StateAdaptor : public ScoreState {
  public:
   //! set the before and after states
   StateAdaptor(Model *m, OptimizerState *before, OptimizerState *after);
-  virtual void do_before_evaluate() IMP_OVERRIDE;
-  virtual void do_after_evaluate(DerivativeAccumulator *da) IMP_OVERRIDE;
-  virtual ModelObjectsTemp do_get_inputs() const IMP_OVERRIDE;
-  virtual ModelObjectsTemp do_get_outputs() const IMP_OVERRIDE;
+  virtual void do_before_evaluate() override;
+  virtual void do_after_evaluate(DerivativeAccumulator *da) override;
+  virtual ModelObjectsTemp do_get_inputs() const override;
+  virtual ModelObjectsTemp do_get_outputs() const override;
   IMP_OBJECT_METHODS(StateAdaptor);
 };
 
