@@ -13,7 +13,7 @@ __doc__ = "Fit subunits into a density map with FFT."
 
 multiproc_exception = None
 try:
-    from multiprocessing import Pool
+    import multiprocessing
     # Detect whether we are running Windows Python via Wine. Wine does not
     # currently support some named pipe functions which the multiprocessing
     # module needs: http://bugs.winehq.org/show_bug.cgi?id=17273
@@ -23,6 +23,19 @@ except ImportError as detail:
     multiproc_exception = str(detail)
 
 
+def _get_context():
+    if hasattr(multiprocessing, 'get_context'):
+        # Use 'forkserver' rather than 'fork' start method if we can;
+        # 'fork' does not work well with multithreaded processes or CUDA
+        if 'forkserver' in multiprocessing.get_all_start_methods():
+            return multiprocessing.get_context('forkserver')
+        else:
+            return multiprocessing.get_context()
+    else:
+        # For Python < 3.4, just use the original module
+        return multiprocessing
+
+
 class Fitter(object):
 
     def __init__(
@@ -65,7 +78,7 @@ class Fitter(object):
         mdl = IMP.Model()
         mol2fit = IMP.atom.read_pdb(self.pdb, mdl)
         mh_xyz = IMP.core.XYZs(IMP.core.get_leaves(mol2fit))
-        rb = IMP.atom.create_rigid_body(mol2fit)
+        _ = IMP.atom.create_rigid_body(mol2fit)
         ff = IMP.multifit.FFTFitting()
         ff.set_was_used(True)
         fits = ff.do_global_fitting(dmap, self.threshold, mol2fit,
@@ -161,13 +174,16 @@ Running on a single processor.""" % multiproc_exception, file=sys.stderr)
     if multiproc_exception is None and options.cpus > 1:
         # No point in spawning more processes than components
         nproc = min(options.cpus, asmb_input.get_number_of_component_headers())
-        p = Pool(processes=nproc)
-        out = list(p.imap_unordered(do_work, work_units))
+        ctx = _get_context()
+        p = ctx.Pool(processes=nproc)
+        _ = list(p.imap_unordered(do_work, work_units))
+        p.close()
 
 
 def main():
     args = parse_args()
     run(args.assembly_file, args)
 
+
 if __name__ == "__main__":
     main()
