@@ -2,24 +2,23 @@
 
 from __future__ import print_function
 import IMP.multifit
-from IMP import OptionParser
+from IMP import ArgumentParser
 
 __doc__ = "Generate indexes of fitting solutions."
 
-def parse_args():
-    usage = """%prog [options] <assembly name> <assembly input> <number of fits> <indexes filename>
 
-Generate indexes of fitting solutions.
-"""
-    parser = OptionParser(usage)
-    options, args = parser.parse_args()
-    if len(args) != 4:
-        parser.error("incorrect number of arguments")
-    return options, args
+def parse_args():
+    desc = """Generate indexes of fitting solutions."""
+    p = ArgumentParser(description=desc)
+    p.add_argument("assembly_name", help="name of the assembly")
+    p.add_argument("assembly_file", help="assembly file name")
+    p.add_argument("num_fits", type=int, help="number of fits")
+    p.add_argument("indexes_file", help="indexes file name")
+    return p.parse_args()
 
 
 def run(assembly_name, asmb_fn, num_fits, mapping_fn=""):
-    IMP.base.set_log_level(IMP.WARNING)
+    IMP.set_log_level(IMP.WARNING)
     asmb_input = IMP.multifit.read_settings(asmb_fn)
     asmb_input.set_was_used(True)
     ap_em_fn = asmb_input.get_assembly_header().get_coarse_over_sampled_ap_fn()
@@ -37,18 +36,15 @@ def run(assembly_name, asmb_fn, num_fits, mapping_fn=""):
         for i in range(min(num_fits, len(fits))):
             indexes.append([i])
         IMP.multifit.write_paths(indexes, index_fn)
-        mapping_data.write("|protein|" + name +
-                           "|" + index_fn + "|\n")
+        mapping_data.write("|protein|" + name + "|" + index_fn + "|\n")
     mapping_data.close()
 
 
 def main():
-    options, args = parse_args()
-    asmb_name = args[0]
-    asmb_input = args[1]
-    max_fits = int(args[2])
-    mapping_fn = args[3]
-    run(asmb_name, asmb_input, max_fits, mapping_fn)
+    args = parse_args()
+    run(args.assembly_name, args.assembly_file, args.num_fits,
+        args.indexes_file)
+
 
 if __name__ == "__main__":
     main()
