@@ -2,30 +2,29 @@
 
 from __future__ import print_function
 import IMP.multifit
-from IMP import OptionParser
+from IMP import ArgumentParser
 
 __doc__ = "Write output models as PDB files."
 
 # analyse the ensemble, first we will do the rmsd stuff
 
-def parse_args():
-    usage = """%prog [options] <asmb.input> <proteomics.input>
-           <mapping.input> <combinations> <model prefix>
 
-Write output models.
-"""
-    parser = OptionParser(usage)
-    parser.add_option("-m", "--max", type="int", dest="max", default=None,
-                      help="maximum number of models to write")
-    (options, args) = parser.parse_args()
-    if len(args) != 5:
-        parser.error("incorrect number of arguments")
-    return options, args
+def parse_args():
+    desc = """Write output models."""
+    p = ArgumentParser(description=desc)
+    p.add_argument("-m", "--max", type=int, dest="max", default=None,
+                   help="maximum number of models to write")
+    p.add_argument("assembly_file", help="assembly file name")
+    p.add_argument("proteomics_file", help="proteomics file name")
+    p.add_argument("mapping_file", help="mapping file name")
+    p.add_argument("combinations_file", help="combinations file name")
+    p.add_argument("model_prefix", help="model output file name prefix")
+    return p.parse_args()
 
 
 def run(asmb_fn, proteomics_fn, mapping_fn, combs_fn, model_output, max_comb):
     # get rmsd for subunits
-    mdl = IMP.kernel.Model()
+    mdl = IMP.Model()
     combs = IMP.multifit.read_paths(combs_fn)
     sd = IMP.multifit.read_settings(asmb_fn)
     sd.set_was_used(True)
@@ -45,8 +44,10 @@ def run(asmb_fn, proteomics_fn, mapping_fn, combs_fn, model_output, max_comb):
 
 
 def main():
-    options, args = parse_args()
-    run(args[0], args[1], args[2], args[3], args[4], options.max)
+    args = parse_args()
+    run(args.assembly_file, args.proteomics_file, args.mapping_file,
+        args.combinations_file, args.model_prefix, args.max)
+
 
 if __name__ == "__main__":
     main()
