@@ -2,12 +2,13 @@
 
 from __future__ import print_function
 import IMP.multifit
-from IMP import OptionParser
+from IMP import ArgumentParser
 
 __doc__ = "Compare output models to a reference structure."
 
 # analyse the ensemble, first we will do the rmsd stuff
 
+
 def get_placement_scores_from_coordinates(model_components_coords,
                                           native_components_coords):
     """
@@ -42,7 +43,7 @@ def get_placement_score_from_coordinates(model_coords, native_coords):
     model_centroid = IMP.algebra.get_centroid(model_coords)
     translation_vector = native_centroid - model_centroid
     distance = translation_vector.get_magnitude()
-    if(len(model_coords) != len(native_coords)):
+    if (len(model_coords) != len(native_coords)):
         raise ValueError(
             "Mismatch in the number of members %d %d " % (
                 len(model_coords),
@@ -55,8 +56,8 @@ def get_placement_score_from_coordinates(model_coords, native_coords):
 
 
 def get_rmsd(hierarchy1, hierarchy2):
-    xyz1 = [IMP.core.XYZ(l) for l in IMP.atom.get_leaves(hierarchy1)]
-    xyz2 = [IMP.core.XYZ(l) for l in IMP.atom.get_leaves(hierarchy2)]
+    xyz1 = [IMP.core.XYZ(leaf) for leaf in IMP.atom.get_leaves(hierarchy1)]
+    xyz2 = [IMP.core.XYZ(leaf) for leaf in IMP.atom.get_leaves(hierarchy2)]
     return IMP.atom.get_rmsd(xyz1, xyz2)
 
 
@@ -73,17 +74,17 @@ def get_components_placement_scores(assembly, native_assembly, align=False):
                 placement distances of the children. The second list contains
                 the placement angles
     """
-    model_coords_per_child = [get_coordinates(c)
+    model_coords_per_child = [get_coordinates(c)  # noqa: F821
                               for c in assembly.get_children()]
-    native_coords_per_child = [get_coordinates(c)
+    native_coords_per_child = [get_coordinates(c)  # noqa: F821
                                for c in native_assembly.get_children()]
     if align:
         model_coords = []
-        nil = [model_coords.extend(x) for x in model_coords_per_child]
+        _ = [model_coords.extend(x) for x in model_coords_per_child]
         native_coords = []
-        nil = [native_coords.extend(x) for x in native_coords_per_child]
-        T = alg.get_transformation_aligning_first_to_second(model_coords,
-                                                            native_coords)
+        _ = [native_coords.extend(x) for x in native_coords_per_child]
+        T = IMP.algebra.get_transformation_aligning_first_to_second(
+            model_coords, native_coords)
         # get aligned coordinates
         new_model_coords_per_child = []
         for c in model_coords_per_child:
@@ -96,25 +97,24 @@ def get_components_placement_scores(assembly, native_assembly, align=False):
 
 
 def parse_args():
-    usage = """%prog [options] <asmb.input> <proteomics.input>
-           <mapping.input> <combinations>
-
+    desc = """
 Compare output models to a reference structure.
 The reference structure for each subunit is read from the rightmost column
 of the asmb.input file.
 """
-    parser = OptionParser(usage)
-    parser.add_option("-m", "--max", type="int", dest="max", default=None,
-                      help="maximum number of models to compare")
-    (options, args) = parser.parse_args()
-    if len(args) != 4:
-        parser.error("incorrect number of arguments")
-    return options, args
+    p = ArgumentParser(description=desc)
+    p.add_argument("-m", "--max", type=int, dest="max", default=None,
+                   help="maximum number of models to compare")
+    p.add_argument("assembly_file", help="assembly file name")
+    p.add_argument("proteomics_file", help="proteomics file name")
+    p.add_argument("mapping_file", help="mapping file name")
+    p.add_argument("combinations_file", help="combinations file name")
+    return p.parse_args()
 
 
 def run(asmb_fn, proteomics_fn, mapping_fn, combs_fn, max_comb):
     # get rmsd for subunits
-    mdl = IMP.kernel.Model()
+    mdl = IMP.Model()
     combs = IMP.multifit.read_paths(combs_fn)
     sd = IMP.multifit.read_settings(asmb_fn)
     sd.set_was_used(True)
@@ -160,8 +160,10 @@ def run(asmb_fn, proteomics_fn, mapping_fn, combs_fn, max_comb):
 
 
 def main():
-    options, args = parse_args()
-    return run(args[0], args[1], args[2], args[3], options.max)
+    args = parse_args()
+    return run(args.assembly_file, args.proteomics_file, args.mapping_file,
+               args.combinations_file, args.max)
+
 
 if __name__ == "__main__":
     main()
