@@ -5,12 +5,11 @@ import math
 import IMP.multifit
 import IMP.atom
 import IMP.em
-from IMP import OptionParser
-import os
-import sys
+from IMP import ArgumentParser
 
 __doc__ = "Refine fitting subunits into a density map with FFT."
 
+
 class Fitter(object):
 
     def __init__(
@@ -66,14 +65,15 @@ class Fitter(object):
         #
         fits = ff.do_local_fitting(dmap, self.threshold, mol2fit,
                                    self.angle / 180.0 * math.pi,
-                                   self.max_angle / 180.0 *
-                                   math.pi, self.max_trans, num_fits_to_report,
+                                   self.max_angle / 180.0 * math.pi,
+                                   self.max_trans, num_fits_to_report,
                                    do_cluster_fits, self.angles_per_voxel,
-                                   max_clustering_translation, max_clustering_rotation)
+                                   max_clustering_translation,
+                                   max_clustering_rotation)
         fits.set_was_used(True)
         final_fits = fits.best_fits_
         if self.ref_pdb != '':
-            ref_mh = IMP.atom.read_pdb(self.ref_pdb, mdl)
+            ref_mh = IMP.atom.read_pdb(self.ref_pdb, mdl)  # noqa: F821
             ref_mh_xyz = IMP.core.XYZs(IMP.core.get_leaves(ref_mh))
             cur_low = [1e4, 0]
         for i, fit in enumerate(final_fits):
@@ -98,39 +98,36 @@ def do_work(f):
 
 
 def parse_args():
-    usage = """%prog [options] <assembly input> <refined assembly input> <proteomics.input> <mapping.input> <combinations file> <combination index>
-
+    desc = """
 Fit subunits locally around a combination solution with FFT."""
-    parser = OptionParser(usage)
-    parser.add_option("-a", "--angle", dest="angle", type="float",
-                      default=5,
-                      help="angle delta (degrees) for FFT rotational "
-                           "search (default 5)")
+    p = ArgumentParser(description=desc)
+    p.add_argument("-a", "--angle", dest="angle", type=float, default=5,
+                   help="angle delta (degrees) for FFT rotational "
+                        "search (default 5)")
 
-    parser.add_option("-n", "--num", dest="num", type="int",
-                      default=100,
-                      help="Number of fits to report"
-                           "(default 100)")
+    p.add_argument("-n", "--num", dest="num", type=int, default=100,
+                   help="Number of fits to report (default 100)")
 
-    parser.add_option("-v", "--angle_voxel", dest="angle_voxel", type="int",
-                      default=10,
-                      help="Number of angles to keep per voxel"
-                           "(default 10)")
+    p.add_argument("-v", "--angle_voxel", dest="angle_voxel", type=int,
+                   default=10,
+                   help="Number of angles to keep per voxel (default 10)")
 
-    parser.add_option("-t", "--max_trans", dest="max_trans", type="float",
-                      default=10.,
-                      help="maximum translational search in A"
-                      "(default 10)")
+    p.add_argument("-t", "--max_trans", dest="max_trans", type=float,
+                   default=10.,
+                   help="maximum translational search in A (default 10)")
 
-    parser.add_option("-m", "--max_angle", dest="max_angle", type="float",
-                      default=30.,
-                      help="maximum angular search in degrees"
-                      "(default 50)")
-
-    options, args = parser.parse_args()
-    if len(args) != 6:
-        parser.error("incorrect number of arguments")
-    return options, args
+    p.add_argument("-m", "--max_angle", dest="max_angle", type=float,
+                   default=30.,
+                   help="maximum angular search in degrees (default 50)")
+    p.add_argument("assembly_file", help="assembly file name")
+    p.add_argument("ref_assembly_file", help="refined assembly file name")
+    p.add_argument("proteomics_file", help="proteomics file name")
+    p.add_argument("mapping_file", help="mapping file name")
+    p.add_argument("combinations_file", help="combinations file name")
+    p.add_argument("combination_index", type=int,
+                   help="number of the combination to read from the "
+                        "combinations file")
+    return p.parse_args()
 
 
 def run(
@@ -142,8 +139,8 @@ def run(
     comb_ind,
         options):
     # get rmsd for subunits
-    mdl1 = IMP.kernel.Model()
-    mdl2 = IMP.kernel.Model()
+    mdl1 = IMP.Model()
+    mdl2 = IMP.Model()
     combs = IMP.multifit.read_paths(combs_fn)
     asmb_input = IMP.multifit.read_settings(asmb_fn)
     asmb_input.set_was_used(True)
@@ -158,7 +155,7 @@ def run(
 
     ensmb_ref = IMP.multifit.load_ensemble(asmb_input, mdl2, mapping_data)
     ensmb_ref.set_was_used(True)
-    mhs_ref = ensmb_ref.get_molecules()
+    _ = ensmb_ref.get_molecules()
 
     ensmb.load_combination(combs[comb_ind])
 
@@ -178,30 +175,25 @@ def run(
         rb_ref = rbs_ref[i]
         rb = rbs[i]
 
-        initial_transformation = IMP.algebra.get_transformation_from_first_to_second(
-            rb_ref.get_reference_frame(),
-            rb.get_reference_frame())
+        initial_transformation = \
+            IMP.algebra.get_transformation_from_first_to_second(
+                rb_ref.get_reference_frame(), rb.get_reference_frame())
 
         pdb_fn = asmb_input.get_component_header(i).get_filename()
 
-        f = Fitter(
-            em_map, spacing, resolution, origin, asmb_input.get_assembly_header(
-            ).get_threshold(
-            ), pdb_fn, fits_fn, options.angle, options.num, options.angle_voxel,
-            options.max_trans, options.max_angle)
+        f = Fitter(em_map, spacing, resolution, origin,
+                   asmb_input.get_assembly_header().get_threshold(), pdb_fn,
+                   fits_fn, options.angle, options.num, options.angle_voxel,
+                   options.max_trans, options.max_angle)
         f.run_local_fitting(mh, rb, initial_transformation)
 
 
 def main():
-    options, args = parse_args()
-    asmb_input = args[0]
-    asmb_refined_input = args[1]
-    proteomics_fn = args[2]
-    mapping_fn = args[3]
-    combinations_fn = args[4]
-    combination_ind = int(args[5])
-    run(asmb_input, asmb_refined_input, proteomics_fn,
-        mapping_fn, combinations_fn, combination_ind, options)
+    args = parse_args()
+    run(args.assembly_file, args.ref_assembly_file, args.proteomics_file,
+        args.mapping_file, args.combinations_file, args.combination_index,
+        args)
+
 
 if __name__ == "__main__":
     main()
