@@ -2,14 +2,14 @@
  *  \file RMF/NodeHandle.h
  *  \brief Declaration of NodeHandle.
  *
- *  Copyright 2007-2021 IMP Inventors. All rights reserved.
+ *  Copyright 2007-2022 IMP Inventors. All rights reserved.
  *
  */
 
 #ifndef RMF_NODE_HANDLE_H
 #define RMF_NODE_HANDLE_H
 
-#include <boost/shared_ptr.hpp>
+#include <memory>
 #include <string>
 #include <vector>
 
@@ -71,7 +71,7 @@ class RMFEXPORT NodeHandle : public NodeConstHandle {
   }
 #if !defined(SWIG) && !defined(RMF_DOXYGEN)
  public:
-  NodeHandle(NodeID node, boost::shared_ptr<internal::SharedData> shared);
+  NodeHandle(NodeID node, std::shared_ptr<internal::SharedData> shared);
 #endif
 
  public:
