@@ -109,9 +109,6 @@ void MonteCarloWithWte::do_step() {
 }
 
 double MonteCarloWithWte::do_evaluate(const ParticleIndexes &, bool) const {
-  // we don't use evaluate_moved() so don't use either input argument
-  if (get_use_incremental_scoring_function())
-    IMP_THROW("Incremental scoring not supported", ModelException);
   double totenergy = get_scoring_function()->evaluate(false);
   double energy = totenergy;
   if (full_ == false) {
