@@ -11,9 +11,10 @@ class Tests(unittest.TestCase):
 
     def test_modules_installed(self):
         """Check MPI-dependent Python modules"""
-        # Fedora and RHEL 8 only have a Python 3 MPI module; other systems
+        # Fedora and RHEL 8/9 only have a Python 3 MPI module; other systems
         # only have Python 2
-        if 'fedora' in mock_config or 'epel-8' in mock_config:
+        if ('fedora' in mock_config or 'epel-8' in mock_config
+                or 'epel-9' in mock_config):
             if sys.version_info[0] == 2:
                 self.skipTest("No Python2 support for MPI")
         elif sys.version_info[0] >= 3:
